@@ -61,6 +61,14 @@ def main():
 
     # Set up a simple console logger
     logging.basicConfig(level=args.loglevel)
+    logging.addLevelName(
+        logging.WARNING,
+        "\033[1;31m%s\033[1;0m" % logging.getLevelName(logging.WARNING)
+    )
+    logging.addLevelName(
+        logging.ERROR,
+        "\033[1;41m%s\033[1;0m" % logging.getLevelName(logging.ERROR)
+    )
 
     # Get configuration object
     logger.info(
